@@ -14,7 +14,7 @@ from struct import unpack
 
 from bluetooth_data_tools import short_address
 from bluetooth_sensor_state_data import BluetoothData
-from home_assistant_bluetooth import BluetoothServiceInfo
+from habluetooth import BluetoothServiceInfoBleak
 from sensor_state_data import BinarySensorDeviceClass, SensorLibrary
 
 _LOGGER = logging.getLogger(__name__)
@@ -44,7 +44,7 @@ SERVICE_UUID = "0000fff0-0000-1000-8000-00805f9b34fb"
 class ThermoBeaconBluetoothDeviceData(BluetoothData):
     """Date update for ThermoBeacon Bluetooth devices."""
 
-    def _start_update(self, service_info: BluetoothServiceInfo) -> None:
+    def _start_update(self, service_info: BluetoothServiceInfoBleak) -> None:
         """Update from BLE advertisement data."""
         _LOGGER.debug("Parsing thermobeacon BLE advertisement data: %s", service_info)
         if SERVICE_UUID not in service_info.service_uuids:
